@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.005001';
+our $VERSION = '2.006000';
 
 1;
 
@@ -22,7 +22,7 @@ GeoIP2 - Perl API for MaxMind's GeoIP2 web services and databases
 
 =head1 VERSION
 
-version 2.005001
+version 2.006000
 
 =head1 DESCRIPTION
 
@@ -120,8 +120,6 @@ L<https://github.com/maxmind/GeoIP2-perl/issues>.
 If you are having an issue with a MaxMind service that is not specific to the
 client API please see L<http://www.maxmind.com/en/support> for details.
 
-Bugs may be submitted through L<https://github.com/maxmind/GeoIP2-perl/issues>.
-
 =head1 AUTHORS
 
 =over 4
@@ -146,7 +144,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack E. Choroba Florian Ragwitz Graham Knop Mateu X Hunter Michael F. Canzoneri Narsimham Chelluri Patrick Cronin Will Storey
+=for stopwords Andy Jack E. Choroba Florian Ragwitz Graham Knop Mateu X Hunter Michael F. Canzoneri Narsimham Chelluri Patrick Cronin William Storey
 
 =over 4
 
@@ -184,7 +182,7 @@ Patrick Cronin <PatrickCronin@users.noreply.github.com>
 
 =item *
 
-Will Storey <will@summercat.com>
+William Storey <wstorey@maxmind.com>
 
 =back
 
