@@ -3,7 +3,7 @@ package GeoIP2::Types;
 use strict;
 use warnings;
 
-our $VERSION = '2.005001';
+our $VERSION = '2.006000';
 
 use Data::Validate::IP ();
 use GeoIP2::Error::Type;
@@ -143,7 +143,9 @@ sub MaxMindID () {
 sub MaxMindLicenseKey () {
     return quote_sub(
         q{ GeoIP2::Types::_tc_fail( $_[0], 'MaxMindLicenseKey' )
-               unless defined $_[0] && $_[0] =~ /^[a-zA-Z0-9]{12}$/; }
+               unless defined $_[0]
+               && ! ref $_[0]
+               && $_[0] =~ /^\S{12,}$/; }
     );
 }
 
